@@ -1,16 +1,16 @@
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 
 import functoins
 
 commands = functoins.commands
 
-def get_command(use):
+def get_command():
 	found = False
 	comand = input(">> ")
 	for com in commands:
 		if comand == com:
-			run = "functoins."+str(com)+"("+str(use)+")"
+			run = "functoins."+str(com)+"()"
 			exec(run)
 			found = True
 			get_command()
